// Auto-generated by scripts/sync_schemas.py

import legislative_standard_dq_dimensions from './legislative/standard_dq_dimensions.json' with { type: 'json' };
import legislative_standard_metrics from './legislative/standard_metrics.json' with { type: 'json' };
import legislative_ontology_graph from './legislative/ontology_graph.json' with { type: 'json' };
import judiciary_standard_data_rules from './judiciary/standard_data_rules.json' with { type: 'json' };
import judiciary_root_cause_factors from './judiciary/root_cause_factors.json' with { type: 'json' };
import executive_business_process_maps from './executive/business_process_maps.json' with { type: 'json' };
import executive_physical_data_map from './executive/physical_data_map.json' with { type: 'json' };

export default {
  legislative_standard_dq_dimensions,
  legislative_standard_metrics,
  legislative_ontology_graph,
  judiciary_standard_data_rules,
  judiciary_root_cause_factors,
  executive_business_process_maps,
  executive_physical_data_map,
};
