import urllib.request
import xml.etree.ElementTree as ET

URL = "https://repository.officiele-overheidspublicaties.nl/bwb/BWBR0005537/2024-01-01_0/xml/BWBR0005537_2024-01-01_0.xml"

print(f"Fetching {URL}...")
with urllib.request.urlopen(URL) as response:
    xml_data = response.read()

root = ET.fromstring(xml_data)
count = 0
for artikel in root.iter("artikel"):
    label = artikel.get("label")
    print(f"Found Article Label: {label}")
    count += 1
    if count > 20:
        break
